Plot Seurat metadata distribution as a bar graph for indicated groups.
MetaDataPlot.RdPlot Seurat metadata distribution as a bar graph for indicated groups.
Usage
MetaDataPlot(
object,
group.by,
split.by,
as.freq = TRUE,
label.count = FALSE,
text.size = 3,
angled.text = TRUE,
label.angle = 45
)Arguments
- object
Seurat object
- group.by
Which meta.data slot to use for assessment
- split.by
Which meta.data slot to use for group splitting
- as.freq
Whether to plot the group.by metadata as a frequency or proportion
- label.count
Whether to add count on top of bar graph
- angled.text
Whether to angle the text to 45 degrees