Run AUCell on a Seurat object
RunAUCell.RdRun AUCell on a Seurat object
Usage
RunAUCell(
object,
assay = NULL,
layer = "counts",
genesets,
ranking.save = FALSE,
ranking.key = NULL,
normAUC = TRUE,
aucMaxRank = 0.05,
verbose = TRUE,
auc_assay_name = "AUC",
...
)Arguments
- object
Seurat object
- assay
Assay to use for building rankings. Will use default assay if NULL.
- layer
layer to use for building rankings
- genesets
A list of vectors of features for expression programs; each entry should be a vector of feature names. If the list of vectors is named, the resulting AUCell score for the expression program will be a row in the AUCell assay returned.
- ranking.save
If TRUE, will save a new Assay `rankings` into `object` with the rankings of each gene per cell.
- ranking.key
If not NULL, will pull Assay `rankings` from `object` rather than re-calculating rankings.
- normAUC
Whether to normalize the maximum possible AUC per geneset to 1
- aucMaxRank
Threshold to calculate the AUC (see details section below and details section of
AUCell_calcAUC)- verbose
Boolean. TRUE to show progress messages, FALSE to hide progress messages
Value
Returns a Seurat object with the AUCell results stored as a Assay object within the Seurat object
Details
(Copied verbatim from AUCell::AUCell_calcAUC) _In a simplified way, the AUC value represents the fraction of genes, within the top X genes in the ranking, that are included in the signature. The parameter 'aucMaxRank' allows to modify the number of genes (maximum ranking) that is used to perform this computation. By default, it is set to 5